describe.vector2 <-  function (x, descript, exclude.missing = TRUE, digits = 4, listunique = 0, 
                              listnchar = 12, weights = NULL, normwt = FALSE, minlength = NULL, 
                              ...) 
{
  oldopt <- options(digits = digits)
  on.exit(options(oldopt))
  if (length(weights) == 0) {
    weights <- rep(1, length(x))
  }
  special.codes <- attr(x, "special.miss")$codes
  labx <- attr(x, "label")
  if (missing(descript)) {
    descript <- as.character(sys.call())[2]
  }
  if (length(labx) && labx != descript) {
    descript <- paste(descript, ":", labx)
  }
  un <- attr(x, "units")
  if (length(un) && un == "") 
    un <- NULL
  fmt <- attr(x, "format")
  if (length(fmt) && (is.function(fmt) || fmt == "")) 
    fmt <- NULL
  if (length(fmt) > 1) 
    fmt <- paste(as.character(fmt[[1]]), as.character(fmt[[2]]))
  present <- if (all(is.na(x))) 
    rep(FALSE, length(x))
  else if (is.character(x)) 
    x != "" & x != " " & !is.na(x)
  else !is.na(x)
  present <- present & !is.na(weights)
  if (length(weights) != length(x)) 
    stop("length of weights must equal length of x")
  if (normwt) {
    weights <- sum(present) * weights/sum(weights[present])
    n <- sum(present)
  }
  else n <- sum(weights[present])
  if (exclude.missing && n == 0) 
    return(structure(NULL, class = "describe"))
  missing <- sum(weights[!present], na.rm = TRUE)
  atx <- attributes(x)
  atx$names <- atx$dimnames <- atx$dim <- atx$special.miss <- NULL
  atx$class <- atx$class[atx$class != "special.miss"]
  isdot <- testDateTime(x, "either")
  isdat <- testDateTime(x, "both")
  x <- x[present, drop = FALSE]
  x.unique <- sort(unique(x))
  weights <- weights[present]
  n.unique <- length(x.unique)
  attributes(x) <- attributes(x.unique) <- atx
  isnum <- (is.numeric(x) || isdat) && !is.factor(x)
  timeUsed <- isdat && testDateTime(x.unique, "timeVaries")
  z <- list(descript = descript, units = un, format = fmt)
  counts <- c(n, missing)
  lab <- c("n", "missing")
  if (length(special.codes)) {
    tabsc <- table(special.codes)
    counts <- c(counts, tabsc)
    lab <- c(lab, names(tabsc))
  }
  if (length(atx$imputed)) {
    counts <- c(counts, length(atx$imputed))
    lab <- c(lab, "imputed")
  }
  if (length(pd <- atx$partial.date)) {
    if ((nn <- length(pd$month)) > 0) {
      counts <- c(counts, nn)
      lab <- c(lab, "missing month")
    }
    if ((nn <- length(pd$day)) > 0) {
      counts <- c(counts, nn)
      lab <- c(lab, "missing day")
    }
    if ((nn <- length(pd$both)) > 0) {
      counts <- c(counts, nn)
      lab <- c(lab, "missing month,day")
    }
  }
  if (length(atx$substi.source)) {
    tabss <- table(atx$substi.source)
    counts <- c(counts, tabss)
    lab <- c(lab, names(tabss))
  }
  counts <- c(counts, n.unique)
  lab <- c(lab, "unique")
  x.binary <- n.unique == 2 && isnum && x.unique[1] == 0 && 
    x.unique[2] == 1
  if (x.binary) {
    counts <- c(counts, sum(weights[x == 1]))
    lab <- c(lab, "Sum")
  }
  # Code to Add Standard Deviation ###############################################
  if (n.unique >= 10 & isnum) {
    xnum <- as.numeric(x)
    if (isdot) {
      dd <- sqrt(wtd.var(xnum, weights=weights))
      fval <- format(dd,...)
      counts <- c(counts, fval)
    }
    else {
      counts <- c(counts, format(sqrt(wtd.var(xnum, weights=weights)),...))
    }
    lab <- c(lab, "sd")
  }
  ################################################################################
  if (isnum) {
    xnum <- unclass(x)
    if (isdot) {
      dd <- sum(weights * xnum)/sum(weights)
      fval <- formatDateTime(dd, atx, !timeUsed)
      counts <- c(counts, fval)
    }
    else counts <- c(counts, format(sum(weights * x)/sum(weights), 
                                    ...))
    lab <- c(lab, "Mean")
  }
  else if (n.unique == 1) {
    counts <- c(counts, format(x.unique))
    lab <- c(lab, "value")
  }
  if (n.unique >= 10 & isnum) {
    q <- if (any(weights != 1)) {
      wtd.quantile(xnum, weights, normwt = FALSE, na.rm = FALSE, 
                   probs = c(0.05, 0.1, 0.25, 0.5, 0.75, 0.9, 0.95))
    }
    else quantile(xnum, c(0.05, 0.1, 0.25, 0.5, 0.75, 0.9, 
                          0.95), na.rm = FALSE)
    fval <- if (isdot) 
      formatDateTime(q, atx, !timeUsed)
    else format(q, ...)
    counts <- c(counts, fval)
    lab <- c(lab, ".05", ".10", ".25", ".50", ".75", ".90", ".95")
  }
  names(counts) <- lab
  z$counts <- counts
  counts <- NULL
  tableIgnoreCaseWhiteSpace <- function(x) {
    x <- gsub("\r", " ", x)
    x <- gsub("^[[:space:]]+", "", gsub("[[:space:]]+$", 
                                        "", x))
    x <- gsub("[[:space:]]+", " ", x)
    y <- tolower(x)
    f <- table(y)
    names(f) <- x[match(names(f), y)]
    f
  }
  if (inherits(x, "mChoice")) 
    z$mChoice <- summary(x, minlength = minlength)
  else {
    if (n.unique <= listunique && !isnum && !is.factor(x) && 
          max(nchar(x)) > listnchar) 
      counts <- tableIgnoreCaseWhiteSpace(x)
    else {
      if (n.unique >= 20) {
        if (isnum) {
          r <- range(xnum)
          xg <- pmin(1 + floor((100 * (xnum - r[1]))/(r[2] - 
                                                        r[1])), 100)
          z$intervalFreq <- list(range = as.single(r), 
                                 count = as.integer(tabulate(xg)))
        }
        loandhi <- x.unique[c(1:5, (n.unique - 4):n.unique)]
        fval <- if (isdot && (class(loandhi) %nin% "timeDate")) {
          formatDateTime(unclass(loandhi), at = atx, 
                         roundDay = !timeUsed)
        }
        else format(format(loandhi), ...)
        counts <- fval
        names(counts) <- c("L1", "L2", "L3", "L4", "L5", 
                           "H5", "H4", "H3", "H2", "H1")
      }
      if (n.unique > 1 && n.unique < 20 && !x.binary) {
        tab <- wtd.table(if (isnum && isdat) 
          format(x)
                         else x, weights, normwt = FALSE, na.rm = FALSE, 
                         type = "table")
        pct <- round(100 * tab/sum(tab))
        counts <- t(as.matrix(tab))
        counts <- rbind(counts, pct)
        dimnames(counts)[[1]] <- c("Frequency", "%")
      }
    }
  }
  z$values <- counts
  structure(z, class = "describe")
}