latex.describe <- 
function (object, title = NULL, condense = TRUE, file = paste("describe", 
    first.word(expr = attr(object, "descript")), "tex", sep = "."), 
    append = FALSE, size = "small", tabular = TRUE, greek = TRUE, 
    ...) 
{
    at <- attributes(object)
    ct <- function(..., file, append = FALSE) {
        if (file == "") 
            cat(...)
        else cat(..., file = file, append = append)
        invisible()
    }
    ct("\\begin{spacing}{0.7}\n", file = file, append = append)
    if (length(at$dimensions)) {
        # Original code commented out AXC
        # ct("\\begin{center}\\bf ", at$descript, "\\\\", at$dimensions[2], 
        #    "Variables~~~~~", at$dimensions[1], "~Observations\\end{center}\n", 
        #    file = file, append = TRUE)
         ct("\\begin{center}\\bf ", 
            at$dimensions[2], "Variables~~~~~", 
            at$dimensions[1], "~Observations\\end{center}\n", 
            file = file, append = TRUE)
        if (length(at$naprint)) 
            ct(at$naprint, "\\\\\n", file = file, append = TRUE)
        ct("\\vspace{-.5ex}\\hrule\\smallskip{\\", size, "\n", 
            sep = "", file = file, append = TRUE)
        vnames <- at$names
        i <- 0
        for (z in object) {
            i <- i + 1
            if (length(z) == 0) 
                next
            ct("\\vbox{", file = file, append = TRUE)
            latex.describe.single(z, condense = condense, vname = vnames[i], 
                file = file, append = TRUE, tabular = tabular, 
                greek = greek)
            ct("\\vspace{-.5ex}\\hrule\\smallskip}\n", file = file, append = TRUE)
        }
        if (length(mv <- at$missing.vars)) {
            ct("\\smallskip\\noindent Variables with all observations missing:\\ \\smallskip\n", 
                file = file, append = TRUE)
            mv <- paste("\\texttt{", mv, "}", sep = "")
            mv <- paste(mv, collapse = ", ")
            ct(mv, file = file, append = TRUE)
        }
        ct("}", file = file, append = TRUE)
    }
    else latex.describe.single(object, vname = first.word(expr = at$descript), 
        condense = condense, file = file, append = TRUE, size = size, 
        tabular = tabular)
    ct("\\end{spacing}\n", file = file, append = TRUE)
    structure(list(file = file, style = c("setspace", "relsize")), class = "latex")
}
