latex.describe.single  <- 
function (object, title = NULL, condense = TRUE, vname, file, 
    append = FALSE, size = "small", tabular = TRUE, greek = TRUE, 
    ...) 
{
    ct <- function(..., file, append = FALSE) {
        if (file == "") 
            cat(...)
        else cat(..., file = file, append = append)
        invisible()
    }
    oldw <- options(width = 85)
    on.exit(options(oldw))
    wide <- switch(size, normalsize = 66, small = 73, scriptsize = 93, 
        73)
    intFreq <- object$intervalFreq
    z <- latexTranslate(object$descript, "&", "\\&", greek = greek)
    des <- if (!length(grep("[^\\]\\$", z))) 
        paste("\\textbf{", z, "}", sep = "")
    else {
        sp <- strsplit(z, " : ")[[1]]
        vnm <- sp[1]
        rem <- paste(sp[-1], collapse = ":")
        paste("\\textbf{", vnm, "}: ", rem, sep = "")
    }
    if (length(object$units)) 
        des <- paste(des, "{\\smaller[1] [", latexTranslate(object$units), 
            "]}", sep = "")
    if (length(object$format)) 
        des <- paste(des, "{\\smaller~~Format:", latexTranslate(object$format), 
            "}", sep = "")
    desbas <- paste(object$descript, if (length(object$units)) 
        paste(" [", object$units, "]", sep = ""), if (length(object$format)) 
        paste("  Format:", object$format, sep = ""))
    ct("\\noindent", des, sep = "", file = file, append = append)
    if (length(intFreq)) {
        counts <- intFreq$count
        maxcounts <- max(counts)
        ct(if (nchar(desbas)/(wide/4.8) > (4.8 - 1.5)) 
            " \\\\ \\mbox{~~~} \n", "\\setlength{\\unitlength}{0.001in}\\hfill", 
            "\\begin{picture}(1.5,.1)(1500,0)", "\\linethickness{0.6pt}\n", 
            sep = "", file = file, append = TRUE)
        for (i in (1:100)[counts > 0]) {
            ct("\\put(", round(1000 * (i - 1) * 1.5/100), ",0){\\line(0,1){", 
                max(1, round(1000 * counts[i]/maxcounts * 0.1)), 
                "}}\n", sep = "", file = file, append = TRUE)
        }
        ct("\\end{picture}\n", file = file, append = TRUE)
    }
    sz <- ""
    if (tabular) {
        ml <- nchar(paste(object$counts, collapse = "  "))
        if (ml > 90) 
            tabular <- FALSE
        else if (ml > 80) 
            sz <- "[2]"
    }
    ct("{\\smaller\n", sz, sep = "", file = file, append = TRUE)
    if (tabular) {
        ct("\\\\ \\begin{tabular}{", paste(rep("r", length(object$counts)), 
            collapse = ""), "}\n", file = file, append = TRUE)
        ct(paste(names(object$counts), collapse = "&"), "\\\\ \n", 
            file = file, append = TRUE)
        ct(paste(object$counts, collapse = "&"), "\\end{tabular}\n", 
            file = file, append = TRUE)
    }
    ct("\\begin{verbatim}\n", file = file, append = TRUE)
    if (file != "") 
        sink(file, append = TRUE)
    if (!tabular) 
        print(object$counts, quote = FALSE)
    if (length(val <- object$values)) {
        if (length(dim(val)) == 0) {
            if (condense) {
                low <- paste("lowest :", paste(val[1:5], collapse = " "))
                hi <- paste("highest:", paste(val[6:10], collapse = " "))
                cat("\n", low, sep = "")
                if (nchar(low) + nchar(hi) + 2 > wide) 
                  cat("\n")
                else cat(", ")
                cat(hi, "\n")
            }
            else {
                cat("\n")
                print(val, quote = FALSE)
            }
        }
        else {
            lev <- dimnames(val)[[2]]
            if (condense && (mean(nchar(lev)) > 10 | length(lev) < 
                5)) {
                z <- ""
                len <- 0
                cat("\n")
                for (i in 1:length(lev)) {
                  w <- paste(lev[i], " (", val[1, i], ", ", val[2, 
                    i], "%)", sep = "")
                  l <- nchar(w)
                  if (len + l + 2 > wide) {
                    cat(z, "\n")
                    len <- 0
                    z <- ""
                  }
                  if (len == 0) {
                    z <- w
                    len <- l
                  }
                  else {
                    z <- paste(z, ", ", w, sep = "")
                    len <- len + l + 2
                  }
                }
                cat(z, "\n")
            }
            else {
                cat("\n")
                print(val, quote = FALSE)
            }
        }
    }
    cat("\\end{verbatim}\n}\n")
    if (file != "") 
        sink()
    invisible()
}