sas.get <- function (library, member, variables = character(0), ifs = character(0), 
    format.library = library, id, dates. = c("sas", "yymmdd", "yearfrac", "yearfrac2"), 
    keep.log=FALSE, log.file = "_temp_.log", 
    macro = sas.get.macro, data.frame.out = existsFunction("data.frame"), 
    clean.up = TRUE, # AXC Change clean.up = !.R., 
    quiet = FALSE, temp = tempfile("SaS"), formats = TRUE, 
    recode = formats, special.miss = FALSE, sasprog = "sas", 
    as.is = 0.5, check.unique.id = TRUE, force.single = FALSE, 
    where, uncompress = FALSE) 
{
    if (.R. && force.single) 
        stop("force.single does not work under R")
    dates. <- match.arg(dates.)
    fexists <- function(name) {
        w <- file.exists(name)
        attr(w, "which") <- name[w]
        w
    }
    file.is.dir <- if (.R.) {
        function(name) {
            isdir <- file.info(name)$isdir
            isdir && !is.na(isdir)
        }
    }
    else {
        function(name) is.dir(name)
    }
    file.is.readable <- function(name) if (.R.) 
        file.access(name, 4) == 0
    else access(name, 4) == 0
    fileShow <- if (.R.) 
        function(x) file.show(x)
    else function(x) page(filename = x)
    if (recode) 
        formats <- TRUE
    if (missing(formats) || formats) {
        no.format <- all(!fexists(paste(format.library, c("formats.sc2", 
            "formats.sct", "formats.sct01", "formats.sas7bcat"), 
            sep = "/")))
        if (no.format) {
            if ((!missing(formats) && formats) || (!missing(recode) && 
                recode)) 
                warning(paste(paste(format.library, "/formats.sc? or formats.sas7bcat", 
                  sep = ""), " not found. Formatting ignored. \n"))
            formats <- recode <- FALSE
        }
    }
    sasin <- paste(temp, ".3.sas", sep = "")
    sasout1 <- paste(temp, ".1.sas", sep = "")
    sasout2 <- paste(temp, ".2.sas", sep = "")
    sasout3 <- paste(temp, ".4.sas", sep = "")
    sasout4 <- paste(temp, ".5.sas", sep = "")
    nvariables <- length(variables)
    if (nvariables > 0) {
        if (any(jdup <- duplicated(variables))) 
            stop(paste("duplicate variables requested: ", variables[jdup]))
    }
    varstring <- paste(variables, collapse = "\n ")
    ifs <- paste("'", paste(ifs, collapse = ";\n "), "'", sep = "")
    if (length(sasin) != 1) 
        stop("Illegal temporary file name")
    temp.files <- c(sasin, sasout1, sasout2, sasout3, sasout4)
    if (!keep.log) 
        temp.files <- c(temp.files, log.file)
    if (clean.up) 
        on.exit(unlink(temp.files))
    if (missing(member)) 
        stop("SAS member name is required")
    if (missing(library)) 
        stop("SAS library name is required")
    cat(macro, sep = "\n", file = sasin)
    sasds.suffix <- c("sd2", "sd7", "ssd01", "ssd02", "ssd03", 
        "ssd04", "sas7bdat")
    if (library == "") {
        if (uncompress) {
            unix.file <- paste(member, sasds.suffix, sep = ".")
            if (any(fe <- fexists(paste(unix.file, ".gz", sep = "")))) 
                sys(paste("gunzip ", attr(fe, "which"), ".gz", 
                  sep = ""))
            else if (any(fe <- fexists(paste(unix.file, ".Z", 
                sep = "")))) 
                sys(paste("uncompress ", attr(fe, "which"), ".Z", 
                  sep = ""))
        }
        cat("%sas_get(", member, ",\n", "  ", sasout1, ",\n", 
            "  ", sasout2, ",\n", "  ", sasout3, ",\n", "  ", 
            sasout4, ",\n", "  dates=", dates., ",\n", "  vars=", 
            varstring, ",\n", "  ifs=", ifs, ",\n", "  formats=", 
            as.integer(formats), "\n,", "  specmiss=", as.integer(special.miss), 
            ");\n", file = sasin, append = TRUE, sep = "")
    }
    else {
        if (!file.is.dir(library)) 
            stop(paste(sep = "", "library, \"", library, "\", is not a directory"))
        unix.file <- paste(library, "/", member, ".", sasds.suffix, 
            sep = "")
        if (uncompress) {
            if (any(fe <- fexists(paste(unix.file, ".gz", sep = "")))) 
                sys(paste("gunzip ", attr(fe, "which"), ".gz", 
                  sep = ""))
            else if (any(fe <- fexists(paste(unix.file, ".Z", 
                sep = "")))) 
                sys(paste("uncompress ", attr(fe, "which"), ".Z", 
                  sep = ""))
        }
        if (!any(fe <- fexists(unix.file))) {
            stop(paste(sep = "", "Unix file, \"", paste(unix.file, 
                collapse = " "), "\", does not exist"))
        }
        else {
            file.name <- attr(fe, "which")
            if (!file.is.readable(file.name)) {
                stop(paste(sep = "", "You do not have read permission for Unix file, \"", 
                  file.name, "\""))
            }
        }
        cat("libname temp '", library, "';\n", file = sasin, 
            append = TRUE, sep = "")
        cat("libname library '", format.library, "';\n", file = sasin, 
            append = TRUE, sep = "")
        cat("%sas_get(temp.", member, ",\n", "  ", sasout1, ",\n", 
            "  ", sasout2, ",\n", "  ", sasout3, ",\n", "  ", 
            sasout4, ",\n", "  dates=", dates., ",\n", "  vars=", 
            varstring, ",\n", "  ifs=", ifs, ",\n", "  formats=", 
            as.integer(formats), "\n,", "  specmiss=", as.integer(special.miss), 
            ");\n", file = sasin, append = TRUE, sep = "")
    }

 # Code from old version,
  status <- sys(paste(sasprog, sasin, "-log", log.file), output = FALSE)

 # Code from new version, causing the problem
 # status <- sys(paste(shQuote(sasprog), shQuote(sasin), "-log",shQuote(log.file)), output = FALSE)

    if (status != 0) {
        if (!quiet && fexists(log.file)) 
            fileShow(log.file)
        stop(paste("SAS job failed with status", status))
    }
    if (!(fexists(sasout1) && fexists(sasout2))) {
        if (!quiet) 
            fileShow(log.file)
        stop("SAS output files not found")
    }
    vars <- if (.R.) 
        scan(sasout1, list(name = "", type = 0, length = 0, format = "", 
            label = "", n = 0), multi.line = FALSE, sep = "\022", 
            flush = TRUE, comment.char = "", quote = "")
    else scan(sasout1, list(name = "", type = 0, length = 0, 
        format = "", label = "", n = 0), multi.line = FALSE, 
        flush = TRUE, sep = "\022")
    nvar <- length(vars$name)
    if (nvar == 0) {
        if (!quiet) 
            fileShow(log.file)
        stop("First SAS output is empty")
    }
    nrow <- vars$n[1]
    type <- ifelse(vars$type == 2, "character(nrow)", ifelse(force.single | 
        (vars$length < 5 & !.R.), "single(nrow)", "double(nrow)"))
    inlist <- paste("\"", vars$name, "\"=", type, sep = "", collapse = ", ")
    inlist <- parse(text = paste("list(", inlist, ")"))
    ds <- if (.R.) 
        scan(sasout2, eval(inlist), sep = "\022", multi.line = FALSE, 
            flush = TRUE, comment.char = "", quote = "")
    else scan(sasout2, eval(inlist), sep = "\022", multi.line = FALSE, 
        flush = TRUE)
    if (length(ds) < nvariables) {
        m <- variables[is.na(match(variables, names(ds)))]
        if (length(m) > 0) {
            warning(paste(length(m), "requested variables did not exist:", 
                paste("\"", m, "\"", sep = "", collapse = " "), 
                "\n\t(use sas.contents())"))
        }
    }
    format <- vars$format
    format[format == "$"] <- " "
    label <- vars$label
    name <- vars$name
    esasout3 <- formats && fexists(sasout3)
    if (recode && !esasout3) 
        recode <- FALSE
    FORMATS <- NULL
    if (formats && esasout3) {
        FORMATS <- dget(sasout3)
        if (length(FORMATS) == 0) {
            FORMATS <- NULL
            recode <- FALSE
        }
    }
    smiss <- NULL
    if (special.miss && fexists(sasout4)) 
        smiss <- if (.R.) 
            scan(sasout4, list(name = "", code = "", obs = integer(1)), 
                multi.line = FALSE, flush = TRUE, sep = "\022", 
                comment.char = "", quote = "")
        else scan(sasout4, list(name = "", code = "", obs = integer(1)), 
            multi.line = FALSE, flush = TRUE, sep = "\022")
    sasdateform <- c("date", "mmddyy", "yymmdd", "ddmmyy", "yyq", 
        "monyy", "julian", "qtr", "weekdate", "weekdatx", "weekday", 
        "month")
    dateform <- list(as.name("ddmmmyy"), "m/d/y", "y/m/d", "d/m/y", 
        as.name("ddmmmyy"), "mon year", as.name("ddmmmyy"), "mon", 
        as.name("ddmmmyy"), as.name("ddmmmyy"), as.name("ddmmmyy"), 
        "m")
    sastimeform <- c("hhmm", "hour", "mmss", "time")
    timeform <- c("h:m", "h", "m:s", "h:m:s")
    sasdatetimeform <- c("datetime", "tod")
    datetimeform <- list(list(as.name("ddmmmyy"), "h:m:s"), c("m/d/y", 
        " "))
    z <- "%02d%b%Y"
    dateform4 <- c(z, "%02m/%02d/%Y", "%Y/%02m/%02d", "%02d/%02m/%Y", 
        z, "%02m %Y", z, "%02m", z, z, z, "%02m")
    timeform4 <- c("%02H:%02M", "%02H", "%02M:%02S", "%02H:%02M:%02S")
    datetimeform4 <- c("%02d%b%Y %02h:%02m:%02s", "%02m/%02d/%Y")
    if (.R.) {
        days.to.adj <- as.numeric(difftime(ISOdate(1970, 1, 1, 
            0, 0, 0), ISOdate(1960, 1, 1, 0, 0, 0), "days"))
        secs.to.adj <- days.to.adj * 24 * 60 * 60
    }
    for (i in 1:nvar) {
        atr <- list()
        dsi <- ds[[i]]
        fname <- format[i]
        rec <- FALSE
        if (fname != " ") {
            ff <- fname
            if (dates. == "sas" & (m <- match(fname, sasdateform, 
                0)) > 0) {
                dd <- dsi - floor(dsi)
                ddn <- !is.na(dd)
                if (any(ddn) && any(dd[ddn] != 0)) {
                  ll <- 1:length(dd)
                  atr$partial.date <- list(month = ll[dd == 0.5], 
                    day = ll[dd == 0.25], both = ll[dd == 0.75])
                  atr$imputed <- ll[dd != 0]
                  dsi <- floor(dsi)
                }
                dsi <- importConvertDateTime(dsi, "date", "sas", 
                  form = if (.SV4.) 
                    dateform4[m]
                  else dateform[m])
                if (length(atr$imputed)) 
                  attr(dsi, "class") <- c("impute", attr(dsi, 
                    "class"))
                ff <- NULL
            }
            else {
                if ((m <- match(fname, sastimeform, 0)) > 0) {
                  dsi <- importConvertDateTime(dsi, "time", "sas", 
                    form = if (.SV4.) 
                      timeform4[m]
                    else timeform[m])
                  ff <- NULL
                }
                else if ((m <- match(fname, sasdatetimeform, 
                  0)) > 0) {
                  dsi <- importConvertDateTime(dsi, "datetime", 
                    "sas", form = if (.SV4.) 
                      datetimeform4[m]
                    else datetimeform[m])
                  ff <- NULL
                }
            }
            atr$format <- ff
            if (recode & length(g <- FORMATS[[fname]])) {
                labs <- g$labels
                if (!is.logical(recode)) {
                  labs <- if (recode == 1) 
                    paste(g$values, ":", labs, sep = "")
                  else paste(labs, "(", g$values, ")", sep = "")
                }
                dsi <- factor(dsi, g$values, labs)
                atr$sas.codes <- g$values
                rec <- TRUE
            }
        }
        if (data.frame.out && !rec && vars$type[i] == 2 && ((is.logical(as.is) && 
            !as.is) || (is.numeric(as.is) && length(unique(dsi)) < 
            as.is * length(dsi)))) 
            dsi <- factor(dsi, exclude = "")
        if (label[i] != " ") 
            label(dsi) <- label[i]
        if (length(smiss$name)) {
            j <- smiss$name == name[i]
            if (any(j)) {
                atr$special.miss <- list(codes = smiss$code[j], 
                  obs = smiss$obs[j])
                attr(dsi, "class") <- c("special.miss", attr(dsi, 
                  "class"))
            }
        }
        if (!is.null(atr)) 
            attributes(dsi) <- c(attributes(dsi), atr)
        if (missing(where)) 
            ds[[i]] <- dsi
        else assign(name[i], dsi, where = where)
    }
    if (!missing(where)) 
        return(structure(where, class = "where"))
    atr <- list()
    if (missing(id)) {
        if (data.frame.out) 
            atr$row.names <- as.character(1:nrow)
    }
    else {
        idname <- id
        jj <- match(idname, names(ds), 0)
        if (any(jj == 0)) 
            stop(paste("id variable(s) not in dataset:", paste(idname[jj == 
                0], collapse = " ")))
        if (length(idname) == 1) {
            id <- ds[[idname]]
        }
        else {
            id <- as.character(ds[[idname[1]]])
            for (jj in 2:length(idname)) id <- paste(id, as.character(ds[[idname[jj]]]))
        }
        if (check.unique.id) {
            dup <- duplicated(id)
            if (any(dup)) 
                warning(paste("duplicate IDs:", paste(id[dup], 
                  collapse = " ")))
        }
        if (data.frame.out) 
            atr$row.names <- as.character(id)
        else atr$id <- id
    }
    if (!is.null(FORMATS)) 
        atr$formats <- FORMATS
    if (data.frame.out) 
        atr$class <- "data.frame"
    attributes(ds) <- c(attributes(ds), atr)
    ds
}